@@ -9,16 +9,16 @@ Object::Iterate::Tester - test module that uses Object::Iterate
 
 	use Object::Iterate qw( imap );
 	use Object::Iterate::Tester;
-	
+
 	my $object = Object::Iterate::Tester->new();
-	
+
 	my @list = imap { $_ } $object;
 
 =head1 DESCRIPTION
 
 =head1 AUTHOR
 
-brian d foy, E<lt>bdfoy@cpan.orgE<gt>
+brian d foy, C<< <bdfoy@cpan.org> >>
 
 =head1 COPYRIGHT
 
